/*
* Copyright (c) 2003-2004 Yrj Kari-Koskinen, Taavi Hupponen
*
* Permission is hereby granted, free of charge, to any person obtaining a
* copy of this software and associated documentation files (the "Software"),
* to deal in the Software without restriction, including without limitation
* the rights to use, copy, modify, merge, publish, distribute, sublicense,
* and/or sell copies of the Software, and to permit persons to whom the
* Software is furnished to do so, subject to the following conditions:
*
* The above copyright notice and this permission notice shall be included in
* all copies or substantial portions of the Software.
*
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
* IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
* FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
* THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
* LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
* FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
* DEALINGS IN THE SOFTWARE.
*/
package fi.iki.hsivonen.xml;

import gnu.xml.pipeline.EventConsumer;
import gnu.xml.pipeline.EventFilter;

import java.util.Arrays;

import org.xml.sax.Attributes;
import org.xml.sax.SAXException;

/**
 * SAX-filtteri, jolla voi jtt pois halutut elementit
 * (elementNames-taulukossa) tai sisllytt vain halutut elementit. 
 * Toiminta mrytyy boolean drop -parametrin perusteella.
 *
 * 
 * 
 * MUISTA ETT ARRAYN TYTYY OLLA JRJESTETTY!
 * 
 *
 * @author ykk@kallio.tky.hut.fi
 */
public class ElementDropper extends EventFilter {

    /** 
     * Jos drop on true, jtetn elementNames-taulukon elementit
     * pois. Jos drop on false, sisllytetn vain
     * elementNames-taulukon elementit ja kaikki muut jtetn pois.
     */
    private boolean drop;

    /**
     * Tarkistetaanko onko namespace xhtml-namespace.
     */
    private boolean checkNS;

    /** 
     * Sisllytettvt tai poisjtettvt elementtinimet, esim "body"
     * ja "title".
     */
    private String[] elementNames;

    /**
     * Luo uuden ElementDropperin. Jos haluat pudottaa body-elementin,
     * niin luo uusi filtteri nin: <pre> new ElementDropper(nextFilter,
     * new String[] { "body" }, true); </pre>
     * @param next seuraava filtteri
         * @param elementNames sisllytettvt tai poisjtettvt
         * elementtinimet, esim "body" ja "title".
         * @param drop mr, pudotetaanko (true) elementNamesin
         * elementit vai sisllytetnk ne (false)
         */
    public ElementDropper(EventConsumer next, String[] elementNames, boolean drop) {
        this(next, elementNames, drop, true);
    }

    /**
         * Luo uuden ElementDropperin. Jos haluat pudottaa body-elementin,
         * niin luo uusi filtteri nin: <pre> new ElementDropper(nextFilter,
         * new String[] { "body" }, true); </pre>
         * @param next seuraava filtteri
         * @param elementNames sisllytettvt tai poisjtettvt
         * elementtinimet, esim "body" ja "title".
         * @param drop mr, pudotetaanko (true) elementNamesin
         * elementit vai sisllytetnk ne (false)
         * @param checkNS tarkistetaanko pudotettavien elementtien NS
         * 
         * 
         */
    public ElementDropper(EventConsumer next, String[] elementNames, boolean drop, boolean checkNS) {
        super(next);
        setContentHandler(this);
        this.elementNames = elementNames;
        this.drop = drop;
        this.checkNS = checkNS;
    }

    public void endElement(String uri, String local, String qname) throws SAXException {

        if ((!checkNS || "http://www.w3.org/1999/xhtml".equals(uri))
            && ((drop && Arrays.binarySearch(elementNames, local) < 0)
                || (!drop && Arrays.binarySearch(elementNames, local) >= 0))) {
            super.endElement(uri, local, qname);
        }
    }

    public void startElement(String uri, String local, String qname, Attributes attributes) throws SAXException {

        if ((!checkNS || "http://www.w3.org/1999/xhtml".equals(uri))
            && ((drop && Arrays.binarySearch(elementNames, local) < 0)
                || (!drop && Arrays.binarySearch(elementNames, local) >= 0))) {
            super.startElement(uri, local, qname, attributes);
        }
    }
}
