/*
 * Copyright (c) 2003, 2004 Henri Sivonen
 *
 * Permission is hereby granted, free of charge, to any person obtaining a 
 * copy of this software and associated documentation files (the "Software"), 
 * to deal in the Software without restriction, including without limitation 
 * the rights to use, copy, modify, merge, publish, distribute, sublicense, 
 * and/or sell copies of the Software, and to permit persons to whom the 
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in 
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
 * DEALINGS IN THE SOFTWARE.
 */

package fi.iki.hsivonen.template;
import java.io.IOException;

/**
 *
 * @version $Id: Template.java,v 1.13 2004/08/28 16:20:07 hsivonen Exp $
 * @author  hsivonen
 */
public interface Template {

    /** 
     * Returns the DOM representation (DOM Level 2; namespace-aware) of the 
     * template.
     *  
     * The <code>TemplateEngine</code> is only interested in things exposed 
     * through the SAX2 <code>ContentHandler</code>. If you use a 
     * <code>DocumentBuilderFactory</code>, the recommended options are<br>
     * <code>factory.setNamespaceAware(true); // must<br>
     * factory.setExpandEntityReferences(true); // must<br>
     * factory.setCoalescing(true); // recommended<br>
     * factory.setIgnoringComments(true); //recommended<br>
     * factory.setIgnoringElementContentWhitespace(false);<br>
     * factory.setValidating(false);</code>
     *
     * @return the DOM representation of the template
     *
     * @throws IOException if an I/O error occurs
     * @throws DataSourceException if any other difficulty is encountered
     */
    public org.w3c.dom.Document getDocument()
        throws DataSourceException, IOException;

    /** 
     * Returns the last modification date (and time) of the template.
     *
     * @return the last modification date of the template or
     *         <code>null</code> if unknown
     *
     * @throws IOException if an I/O error occurs
     * @throws DataSourceException if any other difficulty is encountered
     */
    public java.util.Date getDateModified()
        throws DataSourceException, IOException;

}
