/*
 * Copyright (c) 2003, 2004 Jussi Koskela
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
package fi.iki.hsivonen.webcache.dependency;

import java.util.Date;
import java.util.LinkedHashSet;
import java.util.Set;

import fi.iki.hsivonen.template.Dependencies;

public class DependencyCollector implements Dependencies {
    
    /** Set of collected dependency keys */
    private LinkedHashSet keySet;

    /** Content expiry date */
    private Date expiryDate;

    /** 
     * Class constructor.
     */
    public DependencyCollector() {
        keySet = new LinkedHashSet();
        expiryDate = null;
    }

    /**
     * Registers a new dependency key.
     * @param key the dependency key
     */
    public void registerKey(String key) {
        keySet.add(key);
    }

    /**
     * Registers a new expiry date. The earliest expiry date remains valid.
     * @param date the expiry date
     */
    public void registerExpiration(Date date) {
        if ((expiryDate == null) || expiryDate.after(date)) {
            expiryDate = date;
        }
    }

    /**
     * Returns the set of dependency keys.
     * @return the set of dependency keys
     */
    public Set getKeys() {
        CacheInvalidator.debug("Returning key set to TE " + keySet);
        return keySet;
    }

    /**
     * Returns the expiry date.
     * @return the expiry date
     */
    public Date getExpiryDate() {
        return expiryDate;
    }
}
